==> icon_forest-1.0.2.tar.gz: lib/amazingneoicons.dart <==
import 'package:flutter/material.dart';

class _AmazingNeoIcons extends IconData {
  const _AmazingNeoIcons(int codePoint)
      : super(codePoint,
            fontFamily: 'amazingneoicons', fontPackage: 'icon_forest');
}

class AmazingNeoIcons {
  static const IconData abacus = _AmazingNeoIcons(0xf101);
  static const IconData ac = _AmazingNeoIcons(0xf102);
  static const IconData accessible = _AmazingNeoIcons(0xf103);
  static const IconData accounts = _AmazingNeoIcons(0xf104);
  static const IconData acorn = _AmazingNeoIcons(0xf105);
  static const IconData addressbook = _AmazingNeoIcons(0xf106);
  static const IconData addresscard = _AmazingNeoIcons(0xf107);
  static const IconData adjust = _AmazingNeoIcons(0xf108);
  static const IconData airplane_alt = _AmazingNeoIcons(0xf109);
  static const IconData airplane = _AmazingNeoIcons(0xf10a);
  static const IconData alarm_clock = _AmazingNeoIcons(0xf10b);
  static const IconData alarm_exclamation = _AmazingNeoIcons(0xf10c);
  static const IconData alarm_plus = _AmazingNeoIcons(0xf10d);
  static const IconData alarm_snooze = _AmazingNeoIcons(0xf10e);
  static const IconData align_cente = _AmazingNeoIcons(0xf10f);
  static const IconData align_justify = _AmazingNeoIcons(0xf110);
  static const IconData align_left = _AmazingNeoIcons(0xf111);
  static const IconData align_right = _AmazingNeoIcons(0xf112);
  static const IconData align_slash = _AmazingNeoIcons(0xf113);
  static const IconData ambulance = _AmazingNeoIcons(0xf114);
  static const IconData analytics = _AmazingNeoIcons(0xf115);
  static const IconData anchor = _AmazingNeoIcons(0xf116);
  static const IconData angle_double_down_circle = _AmazingNeoIcons(0xf117);
  static const IconData angle_double_down_square = _AmazingNeoIcons(0xf118);
  static const IconData angle_double_down = _AmazingNeoIcons(0xf119);
  static const IconData angle_double_left_circle = _AmazingNeoIcons(0xf11a);
  static const IconData angle_double_left_square = _AmazingNeoIcons(0xf11b);
  static const IconData angle_double_left = _AmazingNeoIcons(0xf11c);
  static const IconData angle_double_right_circle = _AmazingNeoIcons(0xf11d);
  static const IconData angle_double_right_square = _AmazingNeoIcons(0xf11e);
  static const IconData angle_double_right = _AmazingNeoIcons(0xf11f);
  static const IconData angle_double_up_circle = _AmazingNeoIcons(0xf120);
  static const IconData angle_double_up_square = _AmazingNeoIcons(0xf121);
  static const IconData angle_double_up = _AmazingNeoIcons(0xf122);
  static const IconData angle_down_alt_circlebacus = _AmazingNeoIcons(0xf123);
  static const IconData angle_down_alt_double_circle = _AmazingNeoIcons(0xf124);
  static const IconData angle_down_alt_double_square = _AmazingNeoIcons(0xf125);
  static const IconData angle_down_alt_double = _AmazingNeoIcons(0xf126);
  static const IconData angle_down_alt_square = _AmazingNeoIcons(0xf127);
  static const IconData angle_down_alt = _AmazingNeoIcons(0xf128);
  static const IconData angle_down_circle = _AmazingNeoIcons(0xf129);
  static const IconData angle_down_square = _AmazingNeoIcons(0xf12a);
  static const IconData angle_dow = _AmazingNeoIcons(0xf12b);
  static const IconData angle_left_alt_circle = _AmazingNeoIcons(0xf12c);
  static const IconData angle_left_alt_double = _AmazingNeoIcons(0xf12d);
  static const IconData angle_left_alt_doublet_circle =
      _AmazingNeoIcons(0xf12e);
  static const IconData angle_left_alt_doublet_square =
      _AmazingNeoIcons(0xf12f);
  static const IconData angle_left_alt_square = _AmazingNeoIcons(0xf130);
  static const IconData angle_left_alt = _AmazingNeoIcons(0xf131);
  static const IconData angle_left_circle = _AmazingNeoIcons(0xf132);
  static const IconData angle_left_square = _AmazingNeoIcons(0xf133);
  static const IconData angle_left = _AmazingNeoIcons(0xf134);
  static const IconData angle_right_alt_circle = _AmazingNeoIcons(0xf135);
  static const IconData angle_right_alt_double_circle =
      _AmazingNeoIcons(0xf136);
  static const IconData angle_right_alt_double_square =
      _AmazingNeoIcons(0xf137);
  static const IconData angle_right_alt_double = _AmazingNeoIcons(0xf138);
  static const IconData beach = _AmazingNeoIcons(0xf1cb);
  static const IconData archive = _AmazingNeoIcons(0xf147);
  static const IconData auto_rickshaw = _AmazingNeoIcons(0xf17f);
  static const IconData at = _AmazingNeoIcons(0xf17e);
  static const IconData baby = _AmazingNeoIcons(0xf188);
  static const IconData availability = _AmazingNeoIcons(0xf181);
  static const IconData backpac = _AmazingNeoIcons(0xf189);
  static const IconData barcode = _AmazingNeoIcons(0xf1ad);
  static const IconData battery_empty = _AmazingNeoIcons(0xf1bf);
  static const IconData battery_full = _AmazingNeoIcons(0xf1c1);
  static const IconData book = _AmazingNeoIcons(0xf106);
  static const IconData birthday_cake = _AmazingNeoIcons(0xf1d8);
  static const IconData bed_double = _AmazingNeoIcons(0xf1cd);
  static const IconData bitcoin = _AmazingNeoIcons(0xf1dd);
  static const IconData bicycle = _AmazingNeoIcons(0xff1d6);
  static const IconData bus = _AmazingNeoIcons(0xf228);
  static const IconData calculator_sign = _AmazingNeoIcons(0xf22b);
  static const IconData car = _AmazingNeoIcons(0xf243);
  static const IconData an_car_wash = _AmazingNeoIcons(0xf248);
  static const IconData cart = _AmazingNeoIcons(0xf24c);
  static const IconData cart_plus = _AmazingNeoIcons(0xf250);
  static const IconData chart_line = _AmazingNeoIcons(0xf25d);
  static const IconData chart_bar = _AmazingNeoIcons(0xf25d);
  static const IconData city = _AmazingNeoIcons(0xf272);
  static const IconData cloud_upload = _AmazingNeoIcons(0xf288);
  static const IconData coffee = _AmazingNeoIcons(0xf295);
  static const IconData danger = _AmazingNeoIcons(0xf2e7);
  static const IconData dance = _AmazingNeoIcons(0xf2e6);
  static const IconData diamond = _AmazingNeoIcons(0xf2f1);
  static const IconData dice = _AmazingNeoIcons(0xf2f2);
  static const IconData destinatio = _AmazingNeoIcons(0xf2ed);
  static const IconData eiffel_tower = _AmazingNeoIcons(0xf30f);
  static const IconData fingerprint = _AmazingNeoIcons(0xf36f);
  static const IconData galaxy = _AmazingNeoIcons(0xf396);
  static const IconData glass_chairs = _AmazingNeoIcons(0xf39f);
  static const IconData gift = _AmazingNeoIcons(0xf39d);
  static const IconData gift_card = _AmazingNeoIcons(0xf39d);
  static const IconData graduation_cap = _AmazingNeoIcons(0xf3ae);
  static const IconData guitar = _AmazingNeoIcons(0xf3bc);
  static const IconData hairdryer = _AmazingNeoIcons(0xf3c6);
  static const IconData halloween = _AmazingNeoIcons(0xf3c7);
  static const IconData hand = _AmazingNeoIcons(0xf3d1);
  static const IconData hand_clap = _AmazingNeoIcons(0xf3ca);
  static const IconData kaaba = _AmazingNeoIcons(0xf413);
  static const IconData jet = _AmazingNeoIcons(0xf412);
  static const IconData key = _AmazingNeoIcons(0xf414);
  static const IconData laptop = _AmazingNeoIcons(0xf420);
  static const IconData laptop_code = _AmazingNeoIcons(0xf41f);
  static const IconData landmark = _AmazingNeoIcons(0xf41d);
  static const IconData lightbulb_on = _AmazingNeoIcons(0xf42d);
  static const IconData list = _AmazingNeoIcons(0xf43d);
  static const IconData lock = _AmazingNeoIcons(0xf442);
  static const IconData lock_open = _AmazingNeoIcons(0xf444);
  static const IconData login = _AmazingNeoIcons(0xf449);
  static const IconData logout = _AmazingNeoIcons(0xf44b);
  static const IconData logout_alt = _AmazingNeoIcons(0xf44a);
  static const IconData london_eye = _AmazingNeoIcons(0xf44c);
}

==> icon_forest-1.0.9.tar.gz: lib/amazingneoicons.dart <==
import 'package:flutter/material.dart';

/// Amazing Neo icon pack (112 icons)
class _AmazingNeoIcons extends IconData {
  const _AmazingNeoIcons(int codePoint) : super(codePoint, fontFamily: 'amazingneoicons', fontPackage: 'icon_forest');
}

/// constants link to font code point
class AmazingNeoIcons {
  static const IconData abacus = _AmazingNeoIcons(0xf101);
  static const IconData ac = _AmazingNeoIcons(0xf102);
  static const IconData accessible = _AmazingNeoIcons(0xf103);
  static const IconData accounts = _AmazingNeoIcons(0xf104);
  static const IconData acorn = _AmazingNeoIcons(0xf105);
  static const IconData addressbook = _AmazingNeoIcons(0xf106);
  static const IconData addresscard = _AmazingNeoIcons(0xf107);
  static const IconData adjust = _AmazingNeoIcons(0xf108);
  static const IconData airplane_alt = _AmazingNeoIcons(0xf109);
  static const IconData airplane = _AmazingNeoIcons(0xf10a);
  static const IconData alarm_clock = _AmazingNeoIcons(0xf10b);
  static const IconData alarm_exclamation = _AmazingNeoIcons(0xf10c);
  static const IconData alarm_plus = _AmazingNeoIcons(0xf10d);
  static const IconData alarm_snooze = _AmazingNeoIcons(0xf10e);
  static const IconData align_cente = _AmazingNeoIcons(0xf10f);
  static const IconData align_justify = _AmazingNeoIcons(0xf110);
  static const IconData align_left = _AmazingNeoIcons(0xf111);
  static const IconData align_right = _AmazingNeoIcons(0xf112);
  static const IconData align_slash = _AmazingNeoIcons(0xf113);
  static const IconData ambulance = _AmazingNeoIcons(0xf114);
  static const IconData analytics = _AmazingNeoIcons(0xf115);
  static const IconData anchor = _AmazingNeoIcons(0xf116);
  static const IconData angle_double_down_circle = _AmazingNeoIcons(0xf117);
  static const IconData angle_double_down_square = _AmazingNeoIcons(0xf118);
  static const IconData angle_double_down = _AmazingNeoIcons(0xf119);
  static const IconData angle_double_left_circle = _AmazingNeoIcons(0xf11a);
  static const IconData angle_double_left_square = _AmazingNeoIcons(0xf11b);
  static const IconData angle_double_left = _AmazingNeoIcons(0xf11c);
  static const IconData angle_double_right_circle = _AmazingNeoIcons(0xf11d);
  static const IconData angle_double_right_square = _AmazingNeoIcons(0xf11e);
  static const IconData angle_double_right = _AmazingNeoIcons(0xf11f);
  static const IconData angle_double_up_circle = _AmazingNeoIcons(0xf120);
  static const IconData angle_double_up_square = _AmazingNeoIcons(0xf121);
  static const IconData angle_double_up = _AmazingNeoIcons(0xf122);
  static const IconData angle_down_alt_circlebacus = _AmazingNeoIcons(0xf123);
  static const IconData angle_down_alt_double_circle = _AmazingNeoIcons(0xf124);
  static const IconData angle_down_alt_double_square = _AmazingNeoIcons(0xf125);
  static const IconData angle_down_alt_double = _AmazingNeoIcons(0xf126);
  static const IconData angle_down_alt_square = _AmazingNeoIcons(0xf127);
  static const IconData angle_down_alt = _AmazingNeoIcons(0xf128);
  static const IconData angle_down_circle = _AmazingNeoIcons(0xf129);
  static const IconData angle_down_square = _AmazingNeoIcons(0xf12a);
  static const IconData angle_dow = _AmazingNeoIcons(0xf12b);
  static const IconData angle_left_alt_circle = _AmazingNeoIcons(0xf12c);
  static const IconData angle_left_alt_double = _AmazingNeoIcons(0xf12d);
  static const IconData angle_left_alt_doublet_circle = _AmazingNeoIcons(0xf12e);
  static const IconData angle_left_alt_doublet_square = _AmazingNeoIcons(0xf12f);
  static const IconData angle_left_alt_square = _AmazingNeoIcons(0xf130);
  static const IconData angle_left_alt = _AmazingNeoIcons(0xf131);
  static const IconData angle_left_circle = _AmazingNeoIcons(0xf132);
  static const IconData angle_left_square = _AmazingNeoIcons(0xf133);
  static const IconData angle_left = _AmazingNeoIcons(0xf134);
  static const IconData angle_right_alt_circle = _AmazingNeoIcons(0xf135);
  static const IconData angle_right_alt_double_circle = _AmazingNeoIcons(0xf136);
  static const IconData angle_right_alt_double_square = _AmazingNeoIcons(0xf137);
  static const IconData angle_right_alt_double = _AmazingNeoIcons(0xf138);
  static const IconData beach = _AmazingNeoIcons(0xf1cb);
  static const IconData archive = _AmazingNeoIcons(0xf147);
  static const IconData auto_rickshaw = _AmazingNeoIcons(0xf17f);
  static const IconData at = _AmazingNeoIcons(0xf17e);
  static const IconData baby = _AmazingNeoIcons(0xf188);
  static const IconData availability = _AmazingNeoIcons(0xf181);
  static const IconData backpac = _AmazingNeoIcons(0xf189);
  static const IconData barcode = _AmazingNeoIcons(0xf1ad);
  static const IconData battery_empty = _AmazingNeoIcons(0xf1bf);
  static const IconData battery_full = _AmazingNeoIcons(0xf1c1);
  static const IconData book = _AmazingNeoIcons(0xf106);
  static const IconData birthday_cake = _AmazingNeoIcons(0xf1d8);
  static const IconData bed_double = _AmazingNeoIcons(0xf1cd);
  static const IconData bitcoin = _AmazingNeoIcons(0xf1dd);
  static const IconData bicycle = _AmazingNeoIcons(0xff1d6);
  static const IconData bus = _AmazingNeoIcons(0xf228);
  static const IconData calculator_sign = _AmazingNeoIcons(0xf22b);
  static const IconData car = _AmazingNeoIcons(0xf243);
  static const IconData an_car_wash = _AmazingNeoIcons(0xf248);
  static const IconData cart = _AmazingNeoIcons(0xf24c);
  static const IconData cart_plus = _AmazingNeoIcons(0xf250);
  static const IconData chart_line = _AmazingNeoIcons(0xf25d);
  static const IconData chart_bar = _AmazingNeoIcons(0xf25d);
  static const IconData city = _AmazingNeoIcons(0xf272);
  static const IconData cloud_upload = _AmazingNeoIcons(0xf288);
  static const IconData coffee = _AmazingNeoIcons(0xf295);
  static const IconData danger = _AmazingNeoIcons(0xf2e7);
  static const IconData dance = _AmazingNeoIcons(0xf2e6);
  static const IconData diamond = _AmazingNeoIcons(0xf2f1);
  static const IconData dice = _AmazingNeoIcons(0xf2f2);
  static const IconData destinatio = _AmazingNeoIcons(0xf2ed);
  static const IconData eiffel_tower = _AmazingNeoIcons(0xf30f);
  static const IconData fingerprint = _AmazingNeoIcons(0xf36f);
  static const IconData galaxy = _AmazingNeoIcons(0xf396);
  static const IconData glass_chairs = _AmazingNeoIcons(0xf39f);
  static const IconData gift = _AmazingNeoIcons(0xf39d);
  static const IconData gift_card = _AmazingNeoIcons(0xf39d);
  static const IconData graduation_cap = _AmazingNeoIcons(0xf3ae);
  static const IconData guitar = _AmazingNeoIcons(0xf3bc);
  static const IconData hairdryer = _AmazingNeoIcons(0xf3c6);
  static const IconData halloween = _AmazingNeoIcons(0xf3c7);
  static const IconData hand = _AmazingNeoIcons(0xf3d1);
  static const IconData hand_clap = _AmazingNeoIcons(0xf3ca);
  static const IconData kaaba = _AmazingNeoIcons(0xf413);
  static const IconData jet = _AmazingNeoIcons(0xf412);
  static const IconData key = _AmazingNeoIcons(0xf414);
  static const IconData laptop = _AmazingNeoIcons(0xf420);
  static const IconData laptop_code = _AmazingNeoIcons(0xf41f);
  static const IconData landmark = _AmazingNeoIcons(0xf41d);
  static const IconData lightbulb_on = _AmazingNeoIcons(0xf42d);
  static const IconData list = _AmazingNeoIcons(0xf43d);
  static const IconData lock = _AmazingNeoIcons(0xf442);
  static const IconData lock_open = _AmazingNeoIcons(0xf444);
  static const IconData login = _AmazingNeoIcons(0xf449);
  static const IconData logout = _AmazingNeoIcons(0xf44b);
  static const IconData logout_alt = _AmazingNeoIcons(0xf44a);
  static const IconData london_eye = _AmazingNeoIcons(0xf44c);
}
